@@ -1,6 +1,7 @@
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
+#include <stdint.h>
 #include <cmocka.h>
 
 /* A test case that does nothing and succeeds. */
@@ -9,9 +10,9 @@ static void null_test_success(void **state) {
 }
 
 int main(void) {
-    const UnitTest tests[] = {
-        unit_test(null_test_success),
+    const struct CMUnitTest tests[] = {
+        cmocka_unit_test(null_test_success),
     };
 
-    return run_tests(tests);
+    return cmocka_run_group_tests(tests, NULL, NULL);
 }
