@@ -1,12 +1,20 @@
+#include "config.h"
+
 #include <stdarg.h>
 #include <stddef.h>
 #include <setjmp.h>
 #include <cmocka.h>
+#include <cmocka_private.h>
 
 #include <errno.h>
 #include <sys/types.h>
 #include <sys/stat.h>
+#ifdef HAVE_UNISTD_H
 #include <unistd.h>
+#endif
+#ifdef HAVE_IO_H
+#include <io.h>
+#endif
 #include <fcntl.h>
 
 /**************************************
@@ -27,8 +35,9 @@ static void test_assert_return_code_fail(void **state)
 }
 
 int main(void) {
-    const UnitTest tests[] = {
-        unit_test(test_assert_return_code_fail),
+    const struct CMUnitTest tests[] = {
+        cmocka_unit_test(test_assert_return_code_fail),
     };
-    return run_tests(tests);
+
+    return cmocka_run_group_tests(tests, NULL, NULL);
 }
